@@ -27,6 +27,9 @@
  * @author Jason Geiger
  * @author Jeroen Roos
  */
+
+use conf\conf;
+
 $_action="display";
 $error="";
 if (!defined("CLI")) {
@@ -52,7 +55,7 @@ if (!defined("CLI")) {
         $username=$_SERVER["USER"];
         $user=user::getByName($username);
         if (!$user) {
-            throw new CliUserNotValidException($username . " is not a valid user");
+            throw new cliUserNotValidException($username . " is not a valid user");
         }
     }
     $user->lookup();
@@ -105,7 +108,12 @@ if ($_action == "logout") {
             $error="error=PWDFAIL&";
         }
         $this_page=urlencode(preg_replace("/^\//", "", $_SERVER['REQUEST_URI']));
-        redirect("logon.php?" . $error . "redirect=" . $this_page);
+        if (strstr($this_page, "%2Fservice%2F")) {
+            $page = "../logon.php";
+        } else {
+            $page = "logon.php";
+        }
+        redirect($page . "?" . $error . "redirect=" . $this_page);
     }
 
 }
@@ -125,14 +133,8 @@ if (!empty($user) && !($user instanceof anonymousUser)) {
         // to be extra sure, any action, except "search" is replaced by
         // "display".
         $redirect_clean=preg_replace("/action=(?!search).[^&]+/", "action=display", $redirect);
-        if (array_key_exists('HTTPS', $_SERVER) && (conf::get("ssl.force")=="login")) {
-            $redirect_clean = "http://" . $_SERVER['SERVER_NAME'] . $redirect_clean;
-        }
         redirect($redirect_clean, "Redirect");
     }
-    if (array_key_exists('HTTPS', $_SERVER) && (conf::get("ssl.force")=="login")) {
-        redirect(getZophURL("http"), "switch back from https to http");
-    }
 } else if ($user instanceof anonymousUser) {
     user::setCurrent($user);
 } else {
