@@ -52,8 +52,6 @@ class confDefault extends conf {
      */
     protected static function getConfig() {
         static::getConfigInterface();
-        static::getConfigSSL();
-        static::getConfigURL();
         static::getConfigPath();
         static::getConfigMaps();
         static::getConfigImport();
@@ -214,62 +212,6 @@ class confDefault extends conf {
 
     }
 
-    /**
-     * Get config collection for SSL settings
-     */
-    private static function getConfigSSL() {
-        $ssl = new collection();
-
-        $sslForce = new select();
-        $sslForce->setName("ssl.force");
-        $sslForce->setLabel("Force SSL");
-        $sslForce->setDesc("Force users to use https when using Zoph. When connecting " .
-            "to Zoph using http, the user will automatically be redirected to the same " .
-            "URL, but with https. When choosing \"login only\", the user will be " .
-            "redirected back to http after logging in. If your https-site is hosted on " .
-            "a different URL, you will need to define the correct url below.");
-        $sslForce->addOption("never", "Never");
-        $sslForce->addOption("always", "Always");
-        $sslForce->addOption("login", "Login only");
-        $sslForce->setDefault("never");
-        $sslForce->setDeprecated();
-        $ssl[]=$sslForce;
-
-        conf::addGroup($ssl, "ssl", "SSL", "Protect your site against eavesdropping by " .
-            "using https. You will need to configure this in your webserver as well.");
-    }
-
-    /**
-     * Get config collection for url settings
-     */
-    private static function getConfigURL() {
-        $url = new collection();
-
-        $urlHttp = new text();
-        $urlHttp->setName("url.http");
-        $urlHttp->setLabel("Zoph's URL");
-        $urlHttp->setDesc("Override autodetection of Zoph's URL, for example if you " .
-            "use a domainname to access Zoph but get redirected to a different URL.");
-        $urlHttp->setDefault("");
-        // This regex was stolen from http://mathiasbynens.be/demo/url-regex, @stephenhay
-        $urlHttp->setRegex("(^$|^https?:\/\/[^\s\/$.?#].[^\s]*$)");
-        $urlHttp->setDeprecated();
-        $url[]=$urlHttp;
-
-        $urlHttps = new text();
-        $urlHttps->setName("url.https");
-        $urlHttps->setLabel("Zoph's Secure URL");
-        $urlHttps->setDesc("Override autodetection of Zoph's Secure URL (https).");
-        $urlHttps->setDefault("");
-        // This regex was stolen from http://mathiasbynens.be/demo/url-regex, @stephenhay
-        $urlHttps->setRegex("(^$|^https:\/\/[^\s\/$.?#].[^\s]*$)");
-        $urlHttps->setDeprecated();
-        $url[]=$urlHttps;
-
-        conf::addGroup($url, "url", "URLs", "Define the URLs that are used to access " .
-            "Zoph. Only configure this if Zoph cannot determine it automatically.");
-    }
-
     /**
      * Get config collection for Path settings
      */
