@@ -142,7 +142,7 @@ class web extends base {
             log::msg($dir . " does not exist, creating...", log::WARN, log::IMPORT);
             try {
                 file::createDirRecursive($dir);
-            } catch (\FileDirCreationFailedException $e) {
+            } catch (\fileDirCreationFailedException $e) {
                 log::msg($dir . " does not exist, and I can not create it. (" .
                     $e->getMessage() . ")", log::FATAL, log::IMPORT);
                 die();
@@ -222,7 +222,7 @@ class web extends base {
     protected static function autorotate($file) {
         try {
             parent::autorotate($file);
-        } catch (\ImportAutorotException $e) {
+        } catch (\importAutorotException $e) {
             touch($file . ".zophignore");
             log::msg($e->getMessage(), log::FATAL, log::IMPORT);
             die;
@@ -283,7 +283,7 @@ class web extends base {
         $files=file::getFromDir($unpack_dir, true);
         foreach ($files as $import_file) {
             $type=$import_file->type;
-            if ($type == "image" or $type == "archive" or $type == "xml") {
+            if ($type == "image" || $type == "archive" || $type || "xml") {
                 $import_file->setDestination($dir);
                 try {
                     $import_file->move();
