@@ -53,7 +53,7 @@
  *
  * @package Zoph
  */
-class MailMime {
+class mailMime {
     /** @var string Contains the plain text part of the email */
     private $txtbody;
     /** @var string Contains the html part of the email */
@@ -172,12 +172,12 @@ class MailMime {
      * @param string The content type
      * @param string The filename of the attachment.
      * @param string encoding.
-     * @throws MailException
+     * @throws mailException
      */
     public function addAttachmentFromString($filedata, $filename,
             $c_type = 'application/octet-stream', $encoding = 'base64') {
         if (empty($filename)) {
-            throw new MailException("The supplied filename for the attachment can\'t be empty");
+            throw new mailException("The supplied filename for the attachment can\'t be empty");
         }
         $filename = basename($filename);
         $this->parts[] = array(
@@ -211,10 +211,10 @@ class MailMime {
      */
     private function file2str($file_name) {
         if (!is_readable($file_name)) {
-            throw new MailException('File is not readable ' . $file_name);
+            throw new mailException('File is not readable ' . $file_name);
         }
         if (!$fd = fopen($file_name, 'rb')) {
-            throw new MailException('Could not open ' . $file_name);
+            throw new mailException('Could not open ' . $file_name);
         }
         $filesize = filesize($file_name);
         if ($filesize == 0){
@@ -372,7 +372,7 @@ class MailMime {
             }
         }
 
-        if (!empty($this->html_images) AND isset($this->htmlbody)) {
+        if (!empty($this->html_images) && isset($this->htmlbody)) {
             foreach ($this->html_images as $value) {
                 $regex = '#(\s)((?i)src|background|href(?-i))\s*=\s*(["\']?)' .
                     preg_quote($value['name'], '#') .  '\3#';
@@ -387,21 +387,21 @@ class MailMime {
         $attachments = !empty($this->parts)                ? true : false;
         $html_images = !empty($this->html_images)          ? true : false;
         $html        = !empty($this->htmlbody)             ? true : false;
-        $text        = (!$html AND !empty($this->txtbody)) ? true : false;
+        $text        = (!$html && !empty($this->txtbody)) ? true : false;
 
         switch (true) {
-        case $text AND !$attachments:
+        case $text && !$attachments:
             $message = $this->addTextPart($null, $this->txtbody);
             break;
 
-        case !$text AND !$html AND $attachments:
+        case !$text && !$html && $attachments:
             $message = $this->addMixedPart();
             foreach ($this->parts as $part) {
                 $this->addAttachmentPart($message, $part);
             }
             break;
 
-        case $text AND $attachments:
+        case $text && $attachments:
             $message = $this->addMixedPart();
             $this->addTextPart($message, $this->txtbody);
             foreach ($this->parts as $part) {
@@ -409,7 +409,7 @@ class MailMime {
             }
             break;
 
-        case $html AND !$attachments AND !$html_images:
+        case $html && !$attachments && !$html_images:
             if (isset($this->txtbody)) {
                 $message = $this->addAlternativePart($null);
                 $this->addTextPart($message, $this->txtbody);
@@ -419,7 +419,7 @@ class MailMime {
             }
             break;
 
-        case $html AND !$attachments AND $html_images:
+        case $html && !$attachments && $html_images:
             if (isset($this->txtbody)) {
                 $message =$this->addAlternativePart($null);
                 $this->addTextPart($message, $this->txtbody);
@@ -434,7 +434,7 @@ class MailMime {
             }
             break;
 
-        case $html AND $attachments AND !$html_images:
+        case $html && $attachments && !$html_images:
             $message = $this->addMixedPart();
             if (isset($this->txtbody)) {
                 $alt = $this->addAlternativePart($message);
@@ -448,7 +448,7 @@ class MailMime {
             }
             break;
 
-        case $html AND $attachments AND $html_images:
+        case $html && $attachments && $html_images:
             $message = $this->addMixedPart();
             if (isset($this->txtbody)) {
                 $alt = $this->addAlternativePart($message);
