@@ -71,9 +71,9 @@ class person extends zophTable implements Organizer {
     /** @var array Cached Search Array */
     protected static $sacache;
 
-    /** @var location Home address of this person */
+    /** @var place Home address of this person */
     public $home;
-    /** @var location Work address of this person */
+    /** @var place Work address of this person */
     public $work;
 
     /**
@@ -289,11 +289,7 @@ class person extends zophTable implements Organizer {
      */
     public function getName() {
         $this->lookup();
-        if ($this->get("called")) {
-            $name = $this->get("called");
-        } else {
-            $name = $this->get("first_name");
-        }
+        $name = $this->getShortName();
 
         if ($this->get("last_name")) {
             $name .= " " . $this->get("last_name");
@@ -302,6 +298,28 @@ class person extends zophTable implements Organizer {
         return $name;
     }
 
+    /**
+     * Get full name for this person, no 'called' and including middle name
+     * @return string name
+     */
+    public function getFullName() {
+        $fn = array(
+            $this->get("first_name"),
+            $this->get("middle_name"),
+            $this->get("last_name")
+        );
+        // array_filter removes empty elements from the array, to eliminate duplicate spaces
+        return implode(" ", array_filter($fn));
+    }
+
+    /**
+     * Get short name for this person, if 'called' is set, returns 'called' otherwise the first name
+     * @return string name
+     */
+    public function getShortName() {
+        return $this->get("called") ? $this->get("called") : $this->get("first_name");
+    }
+
     /**
      * Get mail address for this person
      * @return string mailaddress
@@ -316,7 +334,7 @@ class person extends zophTable implements Organizer {
      * @return string name
      */
     public function toHTML() {
-        return getName();
+        return $this->getName();
     }
 
     /**
@@ -334,7 +352,14 @@ class person extends zophTable implements Organizer {
                 $this->get("first_name");
         }
 
-        return "<a href=\"person.php?person_id=" . $this->getId() . "\">$name</a>";
+        return "<a href=\"" . $this->getURL() . "\">$name</a>";
+    }
+
+    /**
+     * Get URL for this person
+     */
+    public function getURL() {
+        return "person.php?person_id=" . $this->getId();
     }
 
     /**
@@ -348,6 +373,7 @@ class person extends zophTable implements Organizer {
 
         $display=array(
             translate("called") => e($this->get("called")),
+            translate("full name") => $this->getFullName(),
             translate("date of birth") => create_date_link(e($this->get("dob"))),
             translate("date of death") => create_date_link(e($this->get("dod"))),
             translate("gender") => e($this->getGender()));
@@ -534,6 +560,10 @@ class person extends zophTable implements Organizer {
         return (in_array($this->getId(), $ids) || $user->isAdmin());
     }
 
+    /**
+     * Is the user the creator of this person?
+     * @param user check for this user | current logged on user
+     */
     public function isCreator(user $user=null) {
         if (!$user) {
             $user=user::getCurrent();
@@ -545,6 +575,7 @@ class person extends zophTable implements Organizer {
     /**
      * Lookup person by name;
      * @param string name
+     * @param bool use 'like' lookup instead of exact lookup
      */
     public static function getByName($name, $like=false) {
         if (empty($name)) {
@@ -795,6 +826,8 @@ class person extends zophTable implements Organizer {
      * Get SQL WHERE clause to search for people
      * @param string search string
      * @param bool search for first name
+     * @param string use this as parameter name - necessary when multiple people searches are used in one query
+     *      for example for (person1 AND person2) searches.
      */
     public static function getWhereForSearch($search, $search_first=false, $paramname="search") {
         $where=null;
