@@ -27,6 +27,9 @@ use db\db;
 use db\clause;
 use db\selectHelper;
 
+use template\block;
+use template\template;
+
 /**
  * Photo ratings
  * @author Jeroen Roos
@@ -252,7 +255,7 @@ class rating extends zophTable {
 
             if ($count > 0) {
                 $link["userrating"]=$rating;
-                $graph[$rating]["link"]="search.php?" . http_build_query($link);
+                $graph[$rating]["link"]="photos.php?" . http_build_query($link);
             }
         }
         return $graph;
@@ -291,12 +294,38 @@ class rating extends zophTable {
                     $graph[0]["value"] = translate("not rated");
                 } else {
                     $link["rating"]=array($rating - 0.5, $rating + 0.5);
-                    $graph[$rating]["link"]="search.php?" . http_build_query($link);
+                    $graph[$rating]["link"]="photos.php?" . http_build_query($link);
                 }
             }
         }
 
         return $graph;
 
-     }
+    }
+
+    /**
+     * Create a pulldown to select ratings
+     * @param string name
+     * @param int value to make 'selected'
+     * @return block pulldown template block
+     */
+    public static function createPulldown($name = "rating", $val = null) {
+        $ratingArray = array(
+            "1" => translate("1 - close your eyes", 0),
+            "2" => translate("2", 0),
+            "3" => translate("3", 0),
+            "4" => translate("4", 0),
+            "5" => translate("5 - so so", 0),
+            "6" => translate("6", 0),
+            "7" => translate("7", 0),
+            "8" => translate("8", 0),
+            "9" => translate("9", 0),
+            "10" => translate("10 - museum", 0)
+        );
+        if (empty($val)) {
+            $ratingArray = array("0" => translate("not rated", 0)) + $ratingArray;
+        }
+
+        return template::createPulldown($name, $val, $ratingArray);
+    }
 }
