@@ -26,6 +26,7 @@ use db\select;
 use db\clause;
 use db\param;
 use db\selectHelper;
+use conf\conf;
 
 /**
  * A class representing a user of Zoph
@@ -41,6 +42,8 @@ class user extends zophTable {
     protected static $primaryKeys=array("user_id");
     /** @var array Fields that may not be empty */
     protected static $notNull=array("user_name");
+    /** @var array Fields that are integers */
+    protected static $isInteger=array("user_id", "person_id", "lightbox_id");
     /** @var bool keep keys with insert. In most cases the keys are set by
                   the db with auto_increment */
     protected static $keepKeys = false;
@@ -52,9 +55,9 @@ class user extends zophTable {
 
     /** @var person Person linked to this user */
     public $person;
-    /** @var user_prefs Preferences of this user */
+    /** @var \userPrefs Preferences of this user */
     public $prefs;
-    /** @var lang Holds translations */
+    /** @var \language Holds translations */
     public $lang;
 
     /**
@@ -81,6 +84,13 @@ class user extends zophTable {
         parent::delete(array("prefs", "groups_users"));
     }
 
+    public function lookup() {
+        parent::lookup();
+        if ($this->get("lastlogin") == "") {
+            $this->set("lastlogin", null);
+        }
+    }
+
     /**
      * Lookup the person linked to this user
      */
@@ -268,7 +278,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can see hidden circles
+     * Check whether this user can see hidden circles
      * @return bool user can see hidden circles
      */
     public function canSeeHiddenCircles() {
@@ -276,7 +286,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can see all photos.
+     * Check whether this user can see all photos.
      * This means that the permissions checking is bypassed for this user,
      * as if it is an admin user, but without giving full admin rights
      * @return bool user can see all photos
@@ -286,7 +296,15 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user is allowed to delete photos
+     * Check whether this user is allowed to leave comments
+     * @return bool user can leave comments
+     */
+    public function canLeaveComments() {
+        return ($this->isAdmin() || $this->get("leave_comments"));
+    }
+
+    /**
+     * Check whether this user is allowed to delete photos
      * @return bool user can delete photos
      */
     public function canDeletePhotos() {
@@ -294,7 +312,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can edit, add and delete albums, categories, places and people
+     * Check whether this user can edit, add and delete albums, categories, places and people
      * @return bool user can add, edit and delete albums, categories, places and people
      */
     public function canEditOrganizers() {
@@ -302,7 +320,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can browse people
+     * Check whether this user can browse people
      * @return bool user can see the list of people that are in photos this user can see
      */
     public function canBrowsePeople() {
@@ -310,7 +328,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can see details of people (such as address, birthdate, etc.)
+     * Check whether this user can see details of people (such as address, birthdate, etc.)
      * @return bool user can see details of people
      */
     public function canSeePeopleDetails() {
@@ -318,7 +336,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can browse places
+     * Check whether this user can browse places
      * @return bool user can see the list of places where photos this user can see were taken
      */
     public function canBrowsePlaces() {
@@ -326,7 +344,7 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can browse tracks
+     * Check whether this user can browse tracks
      * @return bool user can see tracks
      */
     public function canBrowseTracks() {
@@ -334,13 +352,21 @@ class user extends zophTable {
     }
 
     /**
-     * Check wheter this user can see details of places (such as address)
+     * Check whether this user can see details of places (such as address)
      * @return bool user can see details of places
      */
     public function canSeePlaceDetails() {
         return ($this->canEditOrganizers() || $this->get("detailed_places"));
     }
 
+    /**
+     * Check wheter this user can rate photos
+     * @return bool user can rate photos
+     */
+    public function canRatePhotos() {
+        return ($this->isAdmin() || $this->get("allow_rating"));
+    }
+
     /**
      * Get array to display information about this user
      * @return array of properties to display
