@@ -97,13 +97,13 @@ abstract class zophTable {
     /**
      * Get ID
      * @return int id
-     * @throws ZophException
+     * @throws zophException
      */
     public function getId() {
         if (sizeof(static::$primaryKeys)==1) {
             return (int) $this->get(static::$primaryKeys[0]);
         } else {
-            throw new ZophException("This class (" . get_class($this) . ") " .
+            throw new zophException("This class (" . get_class($this) . ") " .
               "requires a specific getId() implementation, please report a bug");
         }
     }
@@ -327,14 +327,6 @@ abstract class zophTable {
                 continue;
             }
 
-            if (substr($name,0,7)=="parent_") {
-                $children=array();
-                $this->getBranchIdArray($children);
-                if (in_array($value, $children)) {
-                    die("You cannot set the parent to a child of the current selection!");
-                }
-            }
-
             if ($value === "now()") {
                 /* Lastnotify is normally set to "now()" and should not be escaped */
                 $qry->addSetFunction($name . "=now()");
@@ -346,7 +338,7 @@ abstract class zophTable {
 
         }
 
-        if (sizeOf($qry->getParams()) === 0 || sizeOf($qry->getSet()) === 0) {
+        if (sizeof($qry->getParams()) === 0 || sizeof($qry->getSet()) === 0) {
             return;
         }
 
@@ -361,7 +353,7 @@ abstract class zophTable {
 
     protected function processValues($name, $value, $qry) {
         if ((is_null($value) || $value==="") && in_array($name, static::$notNull)) {
-            throw new NotNullValueIsNullDataException(e($name) . "may not be empty");
+            throw new notNullValueIsNullDataException(e($name) . "may not be empty");
         } else {
             if (in_array($name, static::$isFloat) && empty($value)) {
                 $value = null;
