@@ -29,6 +29,9 @@
  * @copyright 2003 Nixon P. Childs
  */
 
+use conf\conf;
+use template\template;
+
 require_once "include.inc.php";
 
 if (!conf::get("feature.annotate")) {
