@@ -25,8 +25,9 @@ use conf\conf;
 
 use photo\collection;
 
-use template\template;
+use template\block;
 use template\pager;
+use template\template;
 
 use web\request;
 
@@ -69,7 +70,10 @@ if (empty($qs)) {
     $qs=$_qs;
 }
 
-$actionlinks["return"]="photos.php?" .  $qs;
+
+$tplActionlinks=new block("actionlinks", array(
+    "actionlinks"   =>  array("return" => "photos.php?" .  $qs),
+));
 
 $photoCollection = collection::createFromRequest(request::create());
 $toDisplay = $photoCollection->subset($offset, $cells);
@@ -95,7 +99,7 @@ require_once "header.inc.php";
 ?>
   <h1>
 <?php
-echo create_actionlinks($actionlinks);
+echo $tplActionlinks;
 echo $title_bar
 ?>
   </h1>
@@ -158,7 +162,7 @@ if ($displayCount <= 0) {
               <label for="photographer_id__all"><?php echo translate("photographer") ?></label>
               <?php echo person::createPulldown("__photographer_id__all") ?><br>
               <label for="rating__all"><?php echo translate("rating") ?></label>
-              <?php echo create_rating_pulldown(null, "_rating__all") ?><br>
+              <?= rating::createPulldown("_rating__all") ?><br>
               <label for="album__all"><?php echo translate("albums") ?></label>
               <fieldset class="multiple">
                   <?php echo album::createPulldown("_album__all[0]") ?>
@@ -357,7 +361,7 @@ if ($displayCount <= 0) {
                   <label for="rating__<?php echo $photo_id?>">
                     <?php echo translate("rating") ?>
                   </label>
-                  <?php echo create_rating_pulldown($rating, "_rating__$photo_id") ?>
+                  <?= rating::createPulldown("_rating__$photo_id", $rating) ?>
                   <br>
                 <?php
             }
@@ -458,11 +462,11 @@ if ($displayCount <= 0) {
     // all the edits made on this page.
     foreach ($clean_vars as $key => $value) {
         if (in_array($key, $queryIgnoreArray)) { continue; }
-        $pager_vars[$key] = $val;
+        $pager_vars[$key] = $value;
     }
     $request_vars = $pager_vars;
     echo new pager($offset, $photoCount, $pageCount, $cells,
-        $user->prefs->get("max_pager_size"), $request_vars, "_off");
+        $user->prefs->get("max_pager_size"), $request_vars, "_off", "edit_photos.php");
 } // if photos
 ?>
 <br>
