@@ -22,6 +22,11 @@
  * @author Jeroen Roos
  */
 
+use conf\conf;
+
+use template\block;
+use template\template;
+
 header("Content-Type: text/html; charset=utf-8");
 $user=user::getCurrent();
 
@@ -56,6 +61,11 @@ case "import.php":
 case "config.php":
     $scripts[]="js/conf.js";
     break;
+case "photo.php":
+case "place.php":
+    $scripts[]="js/json.js";
+    $scripts[]="js/locationLookup.js";
+    break;
 }
 
 if (conf::get("interface.autocomplete")) {
@@ -63,17 +73,18 @@ if (conf::get("interface.autocomplete")) {
 }
 
 if (conf::get("maps.provider")) {
-    $scripts[]="js/mxn/mxn.js?(" . conf::get("maps.provider") .")";
+    $scripts[]="js/leaflet-src.js";
     $scripts[]="js/maps.js";
-    $scripts[]="js/custommaps.js";
+    if (conf::get("maps.provider") == "googlev3") {
+        $scripts[]="https://maps.googleapis.com/maps/api/js";
+        $scripts[]="js/leaflet/GoogleMutant.js";
+    } else if (conf::get("maps.provider") == "mapbox") {
+        $javascript[]="var mapbox_api_key = '" . conf::get("maps.mapbox.apikey") . "';";
+    }
+
     if (conf::get("maps.geocode")) {
         $scripts[]="js/geocode.js";
     }
-    switch (strtolower(conf::get("maps.provider"))) {
-    case "googlev3":
-        $scripts[]="https://maps.google.com/maps/api/js?sensor=false";
-        break;
-    }
 }
 
 $html_title=conf::get("interface.title");
@@ -86,13 +97,23 @@ if (isset($title)) {
 <html>
 
 <?php
-$tpl=new block("header", array(
+$hdrParams=array(
     "icons"         => $icons,
     "scripts"       => $scripts,
     "javascript"    => $javascript,
     "extrastyle"    => isset($extrastyle) ? $extrastyle : null,
     "title"         => $html_title
-));
+);
+
+if (isset($prev_url)) {
+    $hdrParams["next"] = $prev_url;
+}
+if (isset($next_url)) {
+    $hdrParams["next"] = $next_url;
+}
+
+$tpl=new block("header", $hdrParams);
+
 
 echo $tpl;
 ?>
