@@ -1,12 +1,14 @@
 <?php
-/*
+/**
+ * Show pagesets
+ *
  * This file is part of Zoph.
  *
  * Zoph is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * Zoph is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -14,27 +16,32 @@
  * You should have received a copy of the GNU General Public License
  * along with Zoph; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * @package Zoph
+ * @author Jeroen Roos
  */
-    require_once("include.inc.php");
-    require_once("header.inc.php");
+require_once "include.inc.php";
+
+$title=translate("Pagesets");
+require_once "header.inc.php";
 ?>
-    <h1>
+<h1>
 <?php
-        if ($user->is_admin()) {
+if ($user->isAdmin()) {
+    ?>
+    <ul class="actionlink">
+      <li><a href="pageset.php?_action=new"><?php echo translate("new") ?></a></li>
+    </ul>
+    <?php
+}
 ?>
-            <span class="actionlink">
-                <a href="pageset.php?_action=new"><?php echo translate("new") ?></a>
-            </span>
+<?php echo $title ?>
+</h1>
+<div class="main">
+  <br>
+  <?php echo pageset::getTable() ?>
+  <br>
+</div>
 <?php
-        }
-?>
-        <?php echo translate("Pagesets") ?>
-    </h1>
-    <div class="main">
-        <br>
-        <?php echo get_all_pagesets() ?>
-        <br>
-    </div>
-<?php
-    require_once("footer.inc.php");
+require_once "footer.inc.php";
 ?>
