@@ -18,6 +18,9 @@
  * along with Zoph; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+
+use template\block;
+
 $url=array_reverse(explode("/", $_SERVER["PHP_SELF"]));
 if ($url[0]=="selection.inc.php") {
     redirect("zoph.php");
@@ -33,8 +36,11 @@ if (!empty($_SESSION["selected_photo"])) {
 
         $selected_photo->lookup();
         unset($selection_actionlinks);
-        $return="_return=photo.php&amp;_qs=" . $encoded_qs;
-        if ($photo && $selected_photo->get("photo_id")!=$photo->get("photo_id")) {
+        $return="_return=photo.php";
+        if (isset($encoded_qs)) {
+            $return.="&amp;_qs=" . $encoded_qs;
+        }
+        if (isset($photo) && $selected_photo->get("photo_id")!=$photo->get("photo_id")) {
             $selection_actionlinks["relate"]="relation.php?_action=new&amp;" .
                 "photo_id_1=" . $selected_photo->get("photo_id") . "&amp;" .
                 "photo_id_2=" . $photo->get("photo_id") . "&amp;" .
@@ -76,7 +82,9 @@ if (!empty($_SESSION["selected_photo"])) {
         ?>
         <div class="thumbnail">
         <?php
-        echo create_actionlinks($selection_actionlinks);
+        $tplActionlinks=new block("actionlinks", array(
+            "actionlinks" => $selection_actionlinks
+        ));
         echo $selected_photo->getImageTag(THUMB_PREFIX);
         ?>
         </div>
