@@ -30,7 +30,7 @@ if (!ZOPH) { die("Illegal call"); }
     <ul class="breadcrumbs <?= $tpl_class ?>">
         <?php foreach ($tpl_crumbs as $crumb): ?>
             <li>
-                <a href="<?= $crumb->getLink() ?>"><?= $crumb->getTitle() ?></a>
+                <a href="<?= $crumb->getURL() ?>"><?= $crumb->getTitle() ?></a>
             </li>
         <?php endforeach; ?>
     </ul>
