@@ -19,12 +19,16 @@
  * @author Jeroen Roos
  */
 
-if (!ZOPH) { die("Illegal call"); }
+use template\template;
+
+if (!ZOPH) {
+    die("Illegal call");
+}
 ?>
 
 <div class="message <?= $tpl_class ?>">
     <img class='icon' src='<?php echo template::getImage("icons/" . $tpl_class . ".png") ?>'>
-    <?= $tpl_text ?>
+    <div class="messageText"><?= $tpl_text ?></div>
     <br>
 </div>
 
