@@ -28,7 +28,7 @@ use conf\conf;
 
 body    {
     font-family: Arial, Verdana, sans-serif;
-    font-size: medium;
+    font-size: 110%;
     color: <?= colorScheme::getColor("text_color") ?>;
     background: <?= colorScheme::getColor("page_bg_color") ?>;
     width: <?= conf::get("interface.width"); ?>;
@@ -49,9 +49,9 @@ h1  {
     text-align: left;
     width: 100%;
     clear: left;
-    font-size: x-large;
+    font-size: 200%;
     font-weight: bold;
-    padding: 2px 10px 2px 10px;
+    padding: 6px 5px 4px 15px;
     box-shadow: 5px 5px 5px rgba(0,0,0,0.4);
     margin: -1px 0;
     z-index: 5;
@@ -77,6 +77,10 @@ h3  {
     font-weight: bold;
 }
 
+h1 .actionlink {
+    font-size: 50%;
+}
+
 /* Unordered list */
 ul  {
     padding-left: 1em;
@@ -110,6 +114,7 @@ ul.thumbs > li dl.extradata {
     display: none;
 }
 
+ul.calendar > li.today,
 ul.thumbs > li.thumb_circle {
     background: <?= colorScheme::getColor("breadcrumb_bg_color") ?>;
     box-shadow: 5px 5px 10px rgba(0,0,0,0.5), 0 0 10px rgba(0,0,0,0.2) inset;
@@ -428,6 +433,7 @@ nav.menu ul li.selected {
 nav.menu ul li a {
     color: <?= colorScheme::getColor("tab_font_color") ?>;
     text-decoration: none;
+    font-size: 120%;
 }
 
 nav.menu ul li.selected > a {
@@ -476,7 +482,7 @@ ul.breadcrumbs li a {
 }
 
 /* Main page */
-.main, .page, div.map, div#selection  {
+.main, .page, div.map, div#selection, div.related  {
     background: <?= colorScheme::getColor("table_bg_color") ?>;
     font-size: medium;
     width: 100%;
@@ -489,6 +495,14 @@ ul.breadcrumbs li a {
     overflow: hidden;
 }
 
+/* when both a 'page' and the normal view are together, fix the
+   border radius and add a small margin */
+.main + .page,
+.page + .main {
+    border-radius: 5px;
+    margin-top: 10px;
+}
+
 .main > div.map {
     left: -1px;
 }
@@ -503,6 +517,11 @@ div.map {
     height: 450px;
 }
 
+div.related {
+    border-radius: 5px;
+    margin-top: 5px;
+}
+
 div.map small {
     display: block;
     /* used in infoBubble */
@@ -865,7 +884,6 @@ ul.actionlink {
     margin: 1px;
     text-align: right;
     vertical-align: top;
-    font-size: 70%;
     float: right;
     font-weight: normal;
     clear: right;
@@ -1003,15 +1021,38 @@ table.permissions input {
     float: none;
 }
 
+nav.calendarhdr ul,
 nav.photohdr ul {
     display: flex;
     justify-content: space-between;
     margin: 10px 0;
 }
 
+nav.calendarhdr ul {
+    margin: 10px 30px;
+}
+
+nav.calendarhdr ul li {
+    padding: 10px;
+    width: 50px;
+}
+nav.calendarhdr ul li a:hover {
+    text-decoration: underline;
+}
 nav.photohdr ul li {
     width: 50px;
 }
+
+nav.calendarhdr ul li.date {
+    padding: 2px;
+    width: 400px;
+}
+nav.calendarhdr ul li.date h2 {
+    text-align: center;
+    font-size: xx-large;
+    font-weight: bold;
+}
+
 nav.photohdr ul li:empty {
     background: transparent;
 }
@@ -1051,6 +1092,7 @@ ul.pagegroup {
     overflow: hidden;
 }
 
+nav.calendarhdr ul li,
 nav.photohdr ul li,
 ul.pagegroup li {
     display: block;
@@ -1061,6 +1103,7 @@ ul.pagegroup li {
     margin: 3px;
 }
 
+nav.calendarhdr ul li a,
 nav.photohdr ul li a,
 ul.pagegroup li a {
     display: block;
@@ -1173,7 +1216,7 @@ ul.photolinks li:hover {
 
 ul.photolinks span.photocount {
     padding: 10px;
-    font-size: xx-large;
+    font-size: x-large;
 }
 
 img.<?= THUMB_PREFIX ?> {
@@ -1221,6 +1264,21 @@ div#personlink  {
     margin: 0 0 15px 0;
 }
 
+ul.peoplelinks {
+    display: block;
+    margin: 1px auto;
+    text-align: center;
+    vertical-align: top;
+    font-size: 80%;
+    font-weight: normal;
+    clear: both;
+}
+
+ul.peoplelinks li {
+    display: inline;
+    margin: 0 0.2em;
+}
+
 /* Text next to an input field, suggesting what to put there, such as "64 chars max" */
 .inputhint  {
     font-size: small;
@@ -1360,14 +1418,33 @@ dl.display > dt {
 }
 
 dl#allexif {
-    display: none;
+    margin: 1em;
+    font-size: 80%;
     width: 100%;
+    overflow: scroll;
 }
 
 dl#allexif dl {
+    clear: left;
+    margin-top: 1.2em;
+    margin-left: -150px;
     width: 100%
 }
 
+dl#allexif dt {
+    width: 40%;
+}
+
+dl#allexif dd {
+    width: 60%;
+}
+
+dl#allexif dd,
+dl#allexif dt {
+    margin: 0;
+    text-align: left;
+}
+
 dl.groups dt {
     margin-top: 0;
     margin-bottom: 10px;
@@ -1829,7 +1906,6 @@ span.filename {
 }
 
 .fn_upload {
-    font-size: 70%;
     margin: 2px;
     display: block;
     float: left;
@@ -1947,7 +2023,8 @@ ul.tabs div.contents > h1 {
 
 ul.tabs div.contents {
     display: block;
-    overflow: hidden;
+    overflow: scroll;
+    max-height: 500px;
     position: relative;
 
     top: -45px;
@@ -1994,22 +2071,24 @@ li.share textarea {
 }
 
 /* Styles for calendar */
-.calendar {
-    text-align: center;
-    vertical-align: top;
-    margin-left: auto; /* To center the page */
-    margin-right: auto;
+
+/**********
+ * Calendar
+ **********/
+ul.calendar li {
+    opacity: 0;
 }
 
-table.calendar .today,
-table.calendar th {
-    font-weight: bold;
+ul.calendar li.day {
+    opacity: 1;
 }
 
-
-.calendar .next,
-.calendar .prev {
-    font-size: x-small;
+ul.calendar li.photos:hover {
+    z-index: 5;
+    margin: -2px;
+    box-shadow: 5px 5px 14px rgba(0,0,0,0.6);
+    width: <?= THUMB_SIZE + 54 ?>px;
+    height: <?= THUMB_SIZE + 74 ?>px;
 }
 
 /* message */
