@@ -30,7 +30,7 @@ if (!ZOPH) {
       <img src="<?php echo template::getImage("icons/share-icon-24x24.png") ?>">
     </div>
     <div class="contents">
-        <h1><?echo translate("share this photo", 0) ?></h1>
+        <h1><?= translate("share this photo", 0) ?></h1>
         <ul class="share">
             <?php if (!empty($tpl_hash)): ?>
                 <li class="direct_link">
