@@ -22,6 +22,8 @@
  */
 require_once "include.inc.php";
 
+use geo\map;
+use geo\point;
 use geo\track;
 
 use photo\collection;
@@ -45,7 +47,7 @@ if (!$user->isAdmin()) {
     $vars=$request->getRequestVarsClean();
     $new_vars=update_query_string($vars, "_action", "do_geotag", array("_test", "_testcount"));
     $photos=collection::createFromRequest($request);
-    $photoCount = sizeOf($photos);
+    $photoCount = sizeof($photos);
 }
 
 if ($_action=="" || $_action=="display") {
